package App::MakeWorld::Mogrify::Copy;

use strict;
use warnings;

our $VERSION = 'v2.5.8';

use App::MakeWorld::Global;
use App::MakeWorld::Check qw[ check ];
use App::MakeWorld::Run;
use App::MakeWorld::Log;

use namespace::clean;

################################################################################
# execute a command

sub verify {

    my ( $class, $opts, $need_hook ) = @_;

    return check( {
            arg  => { required => 1, default => [] },
            dst  => { required => 1 },
            hook => { required => $need_hook },
        },
        $opts
    );
}


sub mogrify {

    require File::Copy::Recursive;


    my ( $class, $pkg, $opts ) = @_;

    my $guard = log_pfx( '<copy>' );

    log_notice( $opts->{arg}, $opts->{dst} );

    foreach my $file ( @{ $opts->{arg} } ) {
        log_info( $file );

        File::Copy::Recursive::rcopy( $file, $opts->{dst} )
          or log_fatal( "error copying $file to $opts->{dst}: $!\n" );
    }

    return;
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Mogrify::Copy

=head1 VERSION

version v2.5.8

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
