package App::MakeWorld::Mogrify::Fillin;

use strict;
use warnings;

our $VERSION = 'v2.5.8';

use File::Spec::Functions qw[ catfile ];
use File::Slurper qw[ read_text write_text ];
use Template::Perlish;


use App::MakeWorld::Global;
use App::MakeWorld::Utils qw[ find_exe ];
use App::MakeWorld::Check qw[ check ];
use App::MakeWorld::Log;
use App::MakeWorld::Interpolate;

use namespace::clean;

sub verify {

    my ( $class, $opts, $need_hook ) = @_;

    return check( {
            tpl       => { required => 1 },
            output    => { required => 1 },
            hook      => { required => $need_hook },
            tag_begin => { default  => '[%' },
            tag_end   => { default  => '%]' },
            vars      => { default  => {} },
        },
        $opts
    );
}


sub mogrify {
    my ( $class, $pkg, $opts ) = @_;

    my $guard = log_pfx( '<fillin>' );

    # find template file
    my $tfile
      = substr( $opts->{tpl}, 0, 2 ) eq './'
      ? $opts->{tpl}
      : (
        grep { -f $_ }
        map { glob( catfile( $_, $opts->{tpl} ) ) } @{ $Opt->srcdir } )[0];

    log_fatal( "couldn't find template file: $opts->{tpl}\n" )
      unless $tfile && -f $tfile;

    log_info( "$tfile $opts->{output}\n" );

    my $vars = interpolate_vars( $opts->{vars}, $pkg->archive );

    my $template = eval { read_text( $tfile ) };
    log_fatal( "unable to open template file $tfile\n" )
      if $@;

    my $tpl = Template::Perlish->new(
        start     => $opts->{tag_begin},
        stop      => $opts->{tag_end},
        variables => $vars,
    ) or log_fatal( "unable to create template object\n" );

    my $output = eval { $tpl->process( $template ); };

    log_fatal( "error filling in template: $tfile: $@\n" )
      if $@;

    eval { write_text( $opts->{output}, $output ) };
    log_fatal( "unable to create template output file: $opts->{output}\n" )
      if $@;

    return;
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Mogrify::Fillin

=head1 VERSION

version v2.5.8

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
