package App::MakeWorld::Mogrify::Patch;

use strict;
use warnings;

our $VERSION = 'v2.5.8';

use File::Spec::Functions qw[ catfile ];

use App::MakeWorld::Global;
use App::MakeWorld::Utils qw[ find_exe ];
use App::MakeWorld::Check qw[ check %BOOLEAN ];
use App::MakeWorld::Run;
use App::MakeWorld::Log;

use namespace::clean;

sub verify {

    my ( $class, $opts, $need_hook ) = @_;

    return check( {
            patch    => { required => 1 },
            hook     => { required => $need_hook },
            exe      => { required => 0 },
            optional => {
                required => 0,
                default  => 0,
                %BOOLEAN
            },
            arg => { default => [] },
        },
        $opts
    );
}

sub mogrify {
    my ( $class, $pkg, $opt ) = @_;

    my $guard = log_pfx( '<patch>' );

    # find patch file
    ( my $file ) = grep { -f $_ }
      map { glob( catfile( $_, $opt->{patch} ) ) } @{ $Opt->srcdir };

    unless ( $file && -f $file ) {
        return if $opt->{optional};
        log_fatal( "non-existent patch file: $opt->{patch}\n" );
    }

    log_notice( "patch" );

    if ( !defined $opt->{exe} ) {

        $opt->{exe} = $Opt->patch_cmd;
        $opt->{arg} = ['-p1'] unless @{ $opt->{arg} };
        push @{ $opt->{arg} }, '-i';
    }

    my @cmd = ( $opt->{exe}, @{ $opt->{arg} }, $file );

    log_info( join( ' ', @cmd ) );

    run( @cmd )
      or log_fatal( "error patching\n" );

    return;
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Mogrify::Patch

=head1 VERSION

version v2.5.8

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
