package App::MakeWorld::Package::Cmake;

use strict;
use warnings;

our $VERSION = 'v2.5.8';

use File::pushd qw[ pushd ];
use Cwd qw[ getcwd ];

use base 'App::MakeWorld::Package';

use App::MakeWorld::Global;
use App::MakeWorld::Run;
use App::MakeWorld::Utils qw[ find_exe ];
use File::Temp qw( tempdir );

use namespace::clean;

sub matches_contents { -f 'CMakeLists.txt' }

sub configure {
    my $self = shift;

    $self->SUPER::configure && return;

    my $config_args = $self->{option}{configure}{arg};

    # just in case
    local %ENV = %ENV;

    # check for configure file. if its a dryrun, it's probable that the
    # source hasn't been unarchived and we won't see the configure file.
    # just assume its there. can't hurt!
    if ( -f 'CMakeLists.txt' || $Opt->dryrun ) {
        my $source_dir = getcwd();
        my $build_dir  = '.';

        if ( !$Opt->dryrun ) {

            unlink( 'CMakeCache.txt' );
            $build_dir = tempdir( DIR => $source_dir )
              or $self->_croak( "error creating temporary build directory\n" );
            $self->set_option( { build_dir => $build_dir } );

        }

        my $guard = pushd( $build_dir );

        run(
            find_exe( 'cmake' ),
            '-DCMAKE_INSTALL_PREFIX=' . $Opt->prefix,
            $config_args, $source_dir,
        ) or $self->_croak( "error configuring package\n" );
    }
}

sub build {
    my $self = shift;

    $self->SUPER::build && return;

    my $guard = pushd( $self->option( 'build_dir' ) );

    run( $Opt->make_cmd )
      or $self->_croak( "error building package\n" );
}

sub test {
    my $self = shift;

    my $guard = pushd( $self->option( 'build_dir' ) );

    $self->SUPER::test
      || $self->_croak( "no test exe specified\n" );
}


sub install {
    my $self = shift;

    $self->SUPER::install && return;

    my $guard = pushd( $self->option( 'build_dir' ) );

    run( $Opt->make_cmd, 'install' )
      or $self->_croak( "error installing package\n" );
}


1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Package::Cmake

=head1 VERSION

version v2.5.8

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
