package App::MakeWorld::Package::PerlModuleBuild;

use strict;
use warnings;

our $VERSION = 'v2.5.8';

use base 'App::MakeWorld::Package';

use File::Spec::Functions qw/ curdir catfile /;

use App::MakeWorld::Global;
use App::MakeWorld::Run;

use namespace::clean;

sub matches_contents { -f 'Build.PL'; }


sub configure {
    my $self = shift;

    $self->SUPER::configure && return;

    # check for configure file. if its a dryrun, it's probable that the
    # source hasn't been unarchived and we won't see the configure file.
    # just assume its there. can't hurt!
    if ( -f 'Build.PL' || $Opt->dryrun ) {
        my @args
          = ( '--install_base', $Opt->prefix, $self->{option}{configure}{arg} );

        run( qw[ perl Build.PL ], @args )
          or $self->_croak( "error configuring package\n" );
    }
}

sub build {
    my $self = shift;

    $self->SUPER::build && return;

    run( catfile( curdir, 'Build' ), 'build', $self->{option}{build}{arg} )
      or $self->_croak( "error building package\n" );
}

sub test {
    my $self = shift;

    $self->SUPER::test && return;

    run( catfile( curdir, 'Build' ), 'test' )
      or $self->_croak( "error testing package\n" );
}


sub install {
    my $self = shift;

    $self->SUPER::install && return;

    run( catfile( curdir, 'Build' ), 'install' )
      or $self->_croak( "error installing package\n" );
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Package::PerlModuleBuild

=head1 VERSION

version v2.5.8

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
